@@ -1,7 +1,8 @@
 from pathlib import Path
 
-from yappa.settings import DEFAULT_CONFIG_FILENAME, DEFAULT_GW_CONFIG_FILENAME
-from yappa.utils import load_yaml, save_yaml
+from yappa.settings import DEFAULT_GW_CONFIG_FILENAME
+from yappa.utils import save_yaml
+from yappa.handlers.common import DEFAULT_CONFIG_FILENAME, load_yaml
 
 
 def create_default_gw_config(filename=DEFAULT_GW_CONFIG_FILENAME):
